Data file was taken from [Download vector maps](https://geojson-maps.ash.ms/).

Original data is from [Natural Earth](https://www.naturalearthdata.com/downloads/). 

Data was originally used in cate. This file has been slightly altered to create 
a separate entry for "French Guyana".
